@@ -1,15 +1,7 @@
-from __future__ import absolute_import, unicode_literals
-
 import os
-import re
 import sys
-import sysconfig
 from abc import ABCMeta, abstractmethod
 
-from six import add_metaclass
-
-from virtualenv.util.six import ensure_text
-
 from .activator import Activator
 
 if sys.version_info >= (3, 7):
@@ -18,8 +10,7 @@ else:
     from importlib_resources import read_binary
 
 
-@add_metaclass(ABCMeta)
-class ViaTemplateActivator(Activator):
+class ViaTemplateActivator(Activator, metaclass=ABCMeta):
     @abstractmethod
     def templates(self):
         raise NotImplementedError
@@ -33,20 +24,12 @@ class ViaTemplateActivator(Activator):
         return generated
 
     def replacements(self, creator, dest_folder):
-        current_platform = sysconfig.get_platform()
-        platforms = ["mingw", "cygwin", "msys"]
-        if any(platform in current_platform for platform in platforms):
-            pattern = re.compile("^([A-Za-z]):(.*)")
-            match = pattern.match(str(creator.dest))
-            virtual_env = "/" + match.group(1).lower() + match.group(2)
-        else:
-            virtual_env = str(creator.dest)
         return {
             "__VIRTUAL_PROMPT__": "" if self.flag_prompt is None else self.flag_prompt,
-            "__VIRTUAL_ENV__": ensure_text(virtual_env),
+            "__VIRTUAL_ENV__": str(creator.dest),
             "__VIRTUAL_NAME__": creator.env_name,
-            "__BIN_NAME__": ensure_text(str(creator.bin_dir.relative_to(creator.dest))),
-            "__PATH_SEP__": ensure_text(os.pathsep),
+            "__BIN_NAME__": str(creator.bin_dir.relative_to(creator.dest)),
+            "__PATH_SEP__": os.pathsep,
         }
 
     def _generate(self, replacements, templates, to_folder, creator):
@@ -73,5 +56,9 @@ class ViaTemplateActivator(Activator):
 
     @staticmethod
     def _repr_unicode(creator, value):
-        # by default we just let it be unicode
-        return value
+        return value  # by default we just let it be unicode
+
+
+__all__ = [
+    "ViaTemplateActivator",
+]
